@@ -202,7 +202,7 @@ static NSString *alarmsFolderURLString = nil;
 
 /* table has the following fields:
      c_path VARCHAR(255) NOT NULL
-     c_name VARCHAR(255) NOT NULLo
+     c_name VARCHAR(255) NOT NULL
      c_uid VARCHAR(255) NOT NULL
      c_recurrence_id INT NULL
      c_alarm_number INT NOT NULL
