@@ -1145,9 +1145,16 @@ andAttribute: (EOAttribute *)_attribute
 			{
         // Update c_startdate for appointments
         if ([theComponent respondsToSelector:@selector(startDate)]) {
+          NSTimeInterval t;
           startDate = [theComponent startDate];
+          t = [startDate timeIntervalSince1970];
           if (startDate) {
-            [quickRow setObject:[NSNumber numberWithUnsignedInt:[startDate timeIntervalSince1970]] forKey:@"c_startdate"];
+            if (t < (long long)INT_MAX && t > (long long)INT_MIN) {
+              [quickRow setObject:[NSNumber numberWithInt: t] forKey:@"c_startdate"];
+            } else {
+              [self errorWithFormat:@"Unexpected value. Invalid start date for timestamp %f", t];
+              [quickRow setObject:[NSNumber numberWithInt: 0] forKey:@"c_startdate"];
+            }
           }
         }
       
