@@ -31,7 +31,7 @@
 */
 
 @class NSString, NSArray, NSURL, NSDictionary, NSException;
-@class GCSChannelManager, GCSAlarmsFolder, GCSFolder, GCSFolderType, GCSSessionsFolder;
+@class GCSChannelManager, GCSAlarmsFolder, GCSAdminFolder, GCSFolder, GCSFolderType, GCSSessionsFolder, GCSOpenIdFolder;
 
 @interface GCSFolderManager : NSObject
 {
@@ -89,6 +89,12 @@
 /* sessions */
 - (GCSSessionsFolder *)sessionsFolder;
 
+/* admin */
+- (GCSAdminFolder *)adminFolder;
+
+/* openid */
+- (GCSOpenIdFolder *) openIdFolder;
+
 /* folder types */
 
 - (GCSFolderType *)folderTypeWithName:(NSString *)_name;
