@@ -76,7 +76,7 @@ fi
 
 if ! [ "$CHECK" = "1" ]; then
    cat >> $SQLFILE <<HERE
-ALTER TABLE $TABLE MODIFY COLUMN c_location integer NULL;
+ALTER TABLE $TABLE MODIFY COLUMN c_location varchar(2048) NULL;
 
 CREATE TABLE sogo_store
 (
@@ -139,12 +139,13 @@ CREATE TABLE sogo_quick_contact
   c_sn character varying(255),
   c_screenname character varying(255),
   c_l character varying(255),
-  c_mail character varying(255),
+  c_mail text,
   c_o character varying(255),
   c_ou character varying(255),
   c_telephonenumber character varying(255),
   c_categories character varying(255),
   c_component character varying(10) NOT NULL,
+  c_hascertificate int4 DEFAULT 0,
   CONSTRAINT sogo_quick_contact_pkey PRIMARY KEY (c_folder_id, c_name)
 );
 
@@ -195,7 +196,7 @@ do
     echo "DROP TABLE $QUICKTABLE;" >> $SQLFILE
     echo "DROP TABLE $STORETABLE;" >> $SQLFILE
     echo "DROP TABLE $ACLTABLE;" >> $SQLFILE
-    echo "UPDATE sogo_folder_info SET c_location = NULL, c_quick_location = NULL, c_acl_location = NULL WHERE c_folder_id = $FOLDERID;" >> $SQLFILE      
+    echo "UPDATE $TABLE SET c_location = NULL, c_quick_location = NULL, c_acl_location = NULL WHERE c_folder_id = $FOLDERID;" >> $SQLFILE
     echo >> $SQLFILE
 done 
 
