@@ -1,8 +1,6 @@
 /* iCalCalendar+SOGo.h - this file is part of SOGo
  *
- * Copyright (C) 2012 Inverse inc
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2012-2017 Inverse inc
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +31,9 @@
 
 - (iCalEvent *) eventWithRecurrenceID: (NSString *) recID;
 - (iCalToDo *) todoWithRecurrenceID: (NSString *) recID;
+- (NSArray *) quickRecordsFromContent: (NSString *) theContent
+                            container: (id) theContainer
+                      nameInContainer: (NSString *) nameInContainer;
 
 @end
 
