@@ -291,6 +291,7 @@ static NSString    *userAgent      = nil;
     {
       [headers setObject: @"true"  forKey: @"receipt"];
       [headers setObject: receipt forKey: @"Disposition-Notification-To"];
+      [headers setObject: receipt forKey: @"Return-Receipt-To"];
     }
   else
     {
@@ -302,12 +303,14 @@ static NSString    *userAgent      = nil;
           if (pureSender)
             {
               [headers setObject: pureSender forKey: @"Disposition-Notification-To"];
+              [headers setObject: pureSender forKey: @"Return-Receipt-To"];
             }
         }
       else
         {
           [headers removeObjectForKey: @"receipt"];
           [headers removeObjectForKey: @"Disposition-Notification-To"];
+          [headers removeObjectForKey: @"Return-Receipt-To"];
         }
     }
 }
@@ -990,7 +993,6 @@ static NSString    *userAgent      = nil;
   [self _fileAttachmentsFromPart: [m body] onlyImages: onlyImages];
 }
 
-
 //
 //
 //
@@ -1019,7 +1021,7 @@ static NSString    *userAgent      = nil;
 
   addresses = [NSMutableArray array];
   [self _addEMailsOfAddresses: [sourceEnvelope from] toArray: addresses];
-  if ([addresses count])
+  if ([addresses count] > 0)
     [info setObject: [addresses objectAtIndex: 0] forKey: @"from"];
   addresses = [NSMutableArray array];
   [self _addEMailsOfAddresses: [sourceEnvelope to] toArray: addresses];
@@ -1035,15 +1037,17 @@ static NSString    *userAgent      = nil;
   addresses = [NSMutableArray array];
   [self _addEMailsOfAddresses: [sourceEnvelope replyTo] toArray: addresses];
   if ([addresses count] > 0)
-    [info setObject: addresses forKey: @"replyTo"];
+    [info setObject: [addresses objectAtIndex: 0] forKey: @"replyTo"];
 
   h = [sourceMail mailHeaders];
   priority = [h objectForKey: @"x-priority"];
   if ([priority isNotEmpty] && [priority isKindOfClass: [NSString class]])
     [info setObject: (NSString*)priority forKey: @"X-Priority"];
   receipt = [h objectForKey: @"disposition-notification-to"];
-  if ([receipt isNotEmpty] && [receipt isKindOfClass: [NSString class]])
+  if ([receipt isNotEmpty] && [receipt isKindOfClass: [NSString class]]) {
     [info setObject: (NSString*)receipt forKey: @"Disposition-Notification-To"];
+    [info setObject: (NSString*)receipt forKey: @"Return-Receipt-To"];
+  }
 
   ud = [[context activeUser] userDefaults];
 
@@ -1893,6 +1897,8 @@ static NSString    *userAgent      = nil;
     [map setObject: s forKey: @"X-Priority"];
   if ([(s = [headers objectForKey: @"Disposition-Notification-To"]) length] > 0)
     [map setObject: s forKey: @"Disposition-Notification-To"];
+  if ([(s = [headers objectForKey: @"Return-Receipt-To"]) length] > 0)
+    [map setObject: s forKey: @"Return-Receipt-To"];
 
   [self _addHeaders: _headers toHeaderMap: map];
 
