@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013 Inverse inc.
+  Copyright (C) 2013-2015 Inverse inc.
 
   This file is part of SOGo.
 
@@ -22,8 +22,6 @@
 #ifndef SOGOMAILLABEL_H
 #define SOGOMAILLABEL_H
 
-#import <Foundation/NSArray.h>
-#import <Foundation/NSString.h>
 
 #import "../../UI/SOGoUI/UIxComponent.h"
 
@@ -43,7 +41,7 @@
 - (NSString *) color;
 
 + (NSArray *) labelsFromDefaults: (NSDictionary *) theDefaults
-                       component: (UIxComponent *) theComponent;
+                       component: (id) theComponent;
 
 @end
 
