@@ -23,7 +23,6 @@
 #ifndef SOGOAUTHENTICATOR_H
 #define SOGOAUTHENTICATOR_H
 
-#import <Foundation/NSObject.h>
 
 @class NSString;
 @class SOGoUser;
@@ -33,6 +32,9 @@
 
 - (NSString *) passwordInContext: (WOContext *) context;
 - (SOGoUser *) userInContext: (WOContext *) context;
+/* To set additionnal cookies (override in subclasses !)*/
+- (NSArray *)getCookiesIfNeeded: (WOContext *)_ctx;
+
 - (NSString *) imapPasswordInContext: (WOContext *) context
                               forURL: (NSURL *) server
                           forceRenew: (BOOL) renew;
