@@ -33,6 +33,8 @@ static const NSString *POLICY_MIN_DIGIT = @"POLICY_MIN_DIGIT";
 static const NSString *POLICY_MIN_SPECIAL_SYMBOLS = @"POLICY_MIN_SPECIAL_SYMBOLS";
 static const NSString *POLICY_MIN_LENGTH = @"POLICY_MIN_LENGTH";
 
+static const NSString *SPECIAL_SYMBOL_ALLOWED = @"%$&*(){}!?\\@#.,:;+=\\[\\]\\|<>\\/-_";
+
 @implementation SOGoPasswordPolicy
 
 - (id) init
@@ -58,7 +60,7 @@ static const NSString *POLICY_MIN_LENGTH = @"POLICY_MIN_LENGTH";
     return [NSArray arrayWithObjects: [NSString stringWithFormat:@"(.*[a-z].*){%i}", [count intValue]], 
                                                           [NSString stringWithFormat:@"(.*[A-Z].*){%i}", [count intValue]], 
                                                           [NSString stringWithFormat:@"(.*[0-9].*){%i}", [count intValue]],  
-                                                          [NSString stringWithFormat:@"([%%$&*(){}!?\\@#.,:;+=].*){%i,}", [count intValue]], 
+                                                          [NSString stringWithFormat:@"([%@].*){%i,}", SPECIAL_SYMBOL_ALLOWED, [count intValue]], 
                                                           [NSString stringWithFormat:@".{%i,}", [count intValue]],
                                                           nil];
 }
@@ -98,12 +100,16 @@ static const NSString *POLICY_MIN_LENGTH = @"POLICY_MIN_LENGTH";
             NSNumber *value = [policy objectForKey:@"value"];
             if (0 < value) {
                 NSString *newLabel = [[translations objectForKey: label] 
-                                    stringByReplacingOccurrencesOfString: @"%{0}"
-                                    withString: [value stringValue]];
+                                     stringByReplacingOccurrencesOfString: @"%{0}"
+                                     withString: [value stringValue]];
+                if ([POLICY_MIN_SPECIAL_SYMBOLS isEqualToString: label]) {
+                    newLabel = [[newLabel stringByAppendingString: @" "]
+                                      stringByAppendingString: SPECIAL_SYMBOL_ALLOWED];
+                }
                 [userTranslatedPasswordPolicy addObject:[NSDictionary dictionaryWithObjectsAndKeys:
-                                                newLabel, @"label", 
-                                                [policy objectForKey:@"regex"], @"regex",
-                                                nil]];
+                                                  newLabel, @"label", 
+                                                  [policy objectForKey:@"regex"], @"regex",
+                                                  nil]];
             } else {
                 // Do nothing
             }
