@@ -1,6 +1,6 @@
 /* SOGoUserDefaults.h - this file is part of SOGo
  *
- * Copyright (C) 2011-2021 Inverse inc.
+ * Copyright (C) 2011-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,14 @@ extern NSString *SOGoWeekStartJanuary1;
 extern NSString *SOGoWeekStartFirst4DayWeek;
 extern NSString *SOGoWeekStartFirstFullWeek;
 
+extern NSString *SOGoPasswordRecoveryDisabled;
+extern NSString *SOGoPasswordRecoveryQuestion;
+extern NSString *SOGoPasswordRecoveryQuestion1;
+extern NSString *SOGoPasswordRecoveryQuestion2;
+extern NSString *SOGoPasswordRecoveryQuestion3;
+extern NSString *SOGoPasswordRecoverySecondaryEmail;
+
+
 @interface SOGoUserDefaults : SOGoDefaultsSource
 {
   NSString *userLanguage;
@@ -111,6 +119,9 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setJunkFolderName: (NSString *) newValue;
 - (NSString *) junkFolderName;
 
+- (void) setTemplatesFolderName: (NSString *) newValue;
+- (NSString *) templatesFolderName;
+
 - (void) setFirstDayOfWeek: (int) newValue;
 - (int) firstDayOfWeek;
 
@@ -142,8 +153,11 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setMailComposeMessageType: (NSString *) newValue;
 - (NSString *) mailComposeMessageType;
 
-- (void) setMailComposeFontSize: (NSString *) newValue;
-- (NSString *) mailComposeFontSize;
+- (void) setMailComposeFontSize: (int) newValue;
+- (int) mailComposeFontSize;
+
+- (void) setMailDisplayFullEmail: (BOOL *) newValue;
+- (BOOL *) mailDisplayFullEmail;
 
 - (void) setMailDisplayRemoteInlineImages: (NSString *) newValue;
 - (NSString *) mailDisplayRemoteInlineImages;
@@ -164,6 +178,13 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setMailSignaturePlacement: (NSString *) newValue;
 - (NSString *) mailSignaturePlacement;
 
+- (BOOL)mailUseSignatureOnNew;
+- (void)setMailUseSignatureOnNew:(BOOL)newValue;
+- (BOOL)mailUseSignatureOnReply;
+- (void)setMailUseSignatureOnReply:(BOOL)newValue;
+- (BOOL)mailUseSignatureOnForward;
+- (void)setMailUseSignatureOnForward:(BOOL)newValue;
+
 - (void) setAllowUserReceipt: (BOOL) allow;
 - (BOOL) allowUserReceipt;
 - (void) setUserReceiptNonRecipientAction: (NSString *) action;
@@ -204,11 +225,17 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setForwardOptions: (NSDictionary *) newValue;
 - (NSDictionary *) forwardOptions;
 
+- (void) setNotificationOptions: (NSDictionary *) newValue;
+- (NSDictionary *) notificationOptions;
+
 - (void) setMailLabelsColors: (NSDictionary *) newValues;
 - (NSDictionary *) mailLabelsColors;
 
+- (void)setHideInlineAttachments:(BOOL)newValue;
+- (BOOL)hideInlineAttachments;
+
 /* calendar */
-- (void) setCalendarCategories: (NSArray *) newValues;
+- (void)setCalendarCategories : (NSArray *)newValues;
 - (NSArray *) calendarCategories;
 
 - (void) setCalendarCategoriesColors: (NSDictionary *) newValues;
@@ -233,6 +260,16 @@ extern NSString *SOGoWeekStartFirstFullWeek;
 - (void) setContactsCategories: (NSArray *) newValues;
 - (NSArray *) contactsCategories;
 
+/* Password recovery */
+- (void) setPasswordRecoveryMode: (NSString *) newValue;
+- (NSString *) passwordRecoveryMode;
+- (void) setPasswordRecoveryQuestion: (NSString *) newValue;
+- (NSString *) passwordRecoveryQuestion;
+- (void) setPasswordRecoveryQuestionAnswer: (NSString *) newValue;
+- (NSString *) passwordRecoveryQuestionAnswer;
+- (void) setPasswordRecoverySecondaryEmail: (NSString *) newValue;
+- (NSString *) passwordRecoverySecondaryEmail;
+
 @end
 
 #endif /* SOGOUSERDEFAULTS_H */
