@@ -29,6 +29,9 @@
 #import <NGObjWeb/WOContext+SoObjects.h>
 #import <NGObjWeb/WEClientCapabilities.h>
 
+#import <SOGo/SOGoSystemDefaults.h>
+#import <SOGo/NSString+Crypto.h>
+
 #import "NSString+Utilities.h"
 #import "SOGoSystemDefaults.h"
 #import "SOGoUserProfile.h"
@@ -86,6 +89,8 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
       [ud setObject: @"text" forKey: @"SOGoMailComposeMessageType"];
     }
 
+  [ud setObject: [NSNumber numberWithUnsignedLongLong: [up getCDefaultsSize]] forKey: @"CDefaultsSize"]; // Add c_defaults field size
+  
   return ud;
 }
 
@@ -629,6 +634,16 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
   return [self integerForKey: @"SOGoMailComposeFontSize"];
 }
 
+- (void) setMailDisplayFullEmail: (BOOL *) newValue
+{
+  [self setBool: newValue forKey: @"SOGoMailDisplayFullEmail"];
+}
+
+- (BOOL *) mailDisplayFullEmail;
+{
+  return [self boolForKey: @"SOGoMailDisplayFullEmail"];
+}
+
 - (void) setMailDisplayRemoteInlineImages: (NSString *) newValue
 {
   [self setObject: newValue forKey: @"SOGoMailDisplayRemoteInlineImages"];
@@ -705,6 +720,36 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
   return signaturePlacement;
 }
 
+- (BOOL) mailUseSignatureOnNew
+{
+  return [self boolForKey: @"SOGoMailUseSignatureOnNew"];
+}
+
+- (void) setMailUseSignatureOnNew: (BOOL) newValue
+{
+  [self setBool: newValue  forKey: @"SOGoMailUseSignatureOnNew"];
+}
+
+- (BOOL) mailUseSignatureOnReply
+{
+  return [self boolForKey: @"SOGoMailUseSignatureOnReply"];
+}
+
+- (void) setMailUseSignatureOnReply: (BOOL) newValue
+{
+  [self setBool: newValue  forKey: @"SOGoMailUseSignatureOnReply"];
+}
+
+- (BOOL) mailUseSignatureOnForward
+{
+  return [self boolForKey: @"SOGoMailUseSignatureOnForward"];
+}
+
+- (void) setMailUseSignatureOnForward: (BOOL) newValue
+{
+  [self setBool: newValue  forKey: @"SOGoMailUseSignatureOnForward"];
+}
+
 - (void) setAllowUserReceipt: (BOOL) allow
 {
   [self setBool: allow forKey: @"SOGoMailReceiptAllow"];
@@ -804,7 +849,7 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
 
   // Remove possible XSS injection
   mailIdentities = [NSMutableArray arrayWithArray: [self arrayForKey: @"SOGoMailIdentities"]];
-  for (i = 0 ; i < [mailIdentities length] ; i++) {
+  for (i = 0 ; i < [mailIdentities count] ; i++) {
     mailIdentity = [NSMutableDictionary dictionaryWithDictionary: [mailIdentities objectAtIndex: i]];
     if (mailIdentity && [mailIdentity objectForKey: @"fullName"]) {
       fullName = [NSString stringWithString: [mailIdentity objectForKey: @"fullName"]];
@@ -927,6 +972,16 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
   return [self objectForKey: @"SOGoMailLabelsColors"];
 }
 
+- (void) setHideInlineAttachments: (BOOL) newValue
+{
+  [self setBool: newValue forKey: @"SOGoMailHideInlineAttachments"];
+}
+
+- (BOOL) hideInlineAttachments
+{
+  return [self boolForKey: @"SOGoMailHideInlineAttachments"];
+}
+
 - (void) setSieveFilters: (NSArray *) newValue
 {
   [self setObject: newValue forKey: @"SOGoSieveFilters"];
@@ -957,6 +1012,16 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
   return [self dictionaryForKey: @"Forward"];
 }
 
+- (void) setNotificationOptions: (NSDictionary *) newValue
+{
+  [self setObject: newValue forKey: @"Notification"];
+}
+
+- (NSDictionary *) notificationOptions
+{
+  return [self dictionaryForKey: @"Notification"];
+}
+
 - (void) setContactsCategories: (NSArray *) newValues
 {
   [self setObject: newValues forKey: @"SOGoContactsCategories"];
