@@ -1,6 +1,6 @@
 /* UIxFolderActions.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2013 Inverse inc.
+ * Copyright (C) 2007-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #ifndef UIXFOLDERACTIONS_H
 #define UIXFOLDERACTIONS_H
 
-#import <NGObjWeb/WODirectAction.h>
 
 @class NSString;
 @class NSMutableString;
@@ -31,7 +30,9 @@
 @class SOGoGCSFolder;
 @class SOGoUserSettings;
 
-@interface UIxFolderActions : WODirectAction
+#include <SOGoUI/SOGoDirectAction.h>
+
+@interface UIxFolderActions : SOGoDirectAction
 {
   SOGoGCSFolder *clientObject;
   LDAPUserManager *um;
@@ -48,6 +49,7 @@
 - (WOResponse *) canAccessContentAction;
 - (WOResponse *) activateFolderAction;
 - (WOResponse *) deactivateFolderAction;
+- (WOResponse *) newguidAction;
 
 @end
 
