@@ -1,8 +1,6 @@
 /* UIxObjectActions.h - this file is part of SOGo
  *
- * Copyright (C) 2007 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2007-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +21,11 @@
 #ifndef UIXOBJECTACTIONS_H
 #define UIXOBJECTACTIONS_H
 
-#import <NGObjWeb/WODirectAction.h>
+#include <SOGoUI/SOGoDirectAction.h>
 
 @class WOResponse;
 
-@interface UIxObjectActions : WODirectAction
+@interface UIxObjectActions : SOGoDirectAction
 
 - (WOResponse *) addUserInAclsAction;
 
