@@ -19,6 +19,8 @@
   02111-1307, USA.
 */
 
+#import <SOGo/SOGoSystemDefaults.h>
+
 #import <Foundation/Foundation.h>
 #import <SoObjects/SOGo/NSArray+Utilities.h>
 #import <SoObjects/SOGo/NSDictionary+Utilities.h>
@@ -51,6 +53,7 @@
 #import <SoObjects/Contacts/SOGoContactGCSFolder.h>
 
 #import <SOGo/NSString+Utilities.h>
+#import <SOGo/SOGoMobileProvision.h>
 
 #import "UIxContactFolderActions.h"
 
@@ -77,35 +80,47 @@ static NSArray *photoTags = nil;
   id currentChild;
   SOGoContactGCSFolder *sourceFolder;
   NSMutableString *content;
+ SOGoSystemDefaults *sd;
 
-  content = [NSMutableString string];
-  sourceFolder = [self clientObject];
-  contactsId = [[[[context request] contentAsString] objectFromJSONString] objectForKey: @"uids"];
+  sd = [SOGoSystemDefaults sharedSystemDefaults];
+  if (nil != [sd disableExport] && NSNotFound != [[sd disableExport] indexOfObject: kDisableSharingContacts])
+  {
+    response = [self responseWithStatus: 401
+                  andJSONRepresentation: [NSDictionary dictionaryWithObject: @"Exporting contacts folder is not authorized"
+                                                                     forKey: @"message"]];
 
-  if (!contactsId)
-    contactsId = [sourceFolder toOneRelationshipKeys];
+  }
+  else
+  {
+    content = [NSMutableString string];
+    sourceFolder = [self clientObject];
+    contactsId = [[[[context request] contentAsString] objectFromJSONString] objectForKey: @"uids"];
 
-  uids = [contactsId objectEnumerator];
-  while ((uid = [uids nextObject]))
-    {
-      currentChild = [sourceFolder lookupName: uid
-                                    inContext: [self context]
-                                      acquire: NO];
-      if ([currentChild respondsToSelector: @selector (vCard)])
-        [content appendFormat: @"%@", [[currentChild ldifRecord] ldifRecordAsString]];
-      else if ([currentChild respondsToSelector: @selector (vList)])
-        [content appendFormat: @"%@", [[currentChild vList] ldifString]];
-      [content appendString: @"\n"];
-    }
+    if (!contactsId)
+      contactsId = [sourceFolder toOneRelationshipKeys];
 
-  response = [context response];
-  [response setHeader: @"application/directory; charset=utf-8"
-               forKey: @"content-type"];
-  filename = [NSString stringWithFormat: @"%@.ldif",
-                       [[sourceFolder displayName] asQPSubjectString: @"utf-8"]];
-  disposition = [NSString stringWithFormat: @"attachment; filename=\"%@\"", filename];
-  [response setHeader: disposition forKey: @"Content-Disposition"];
-  [response setContent: [content dataUsingEncoding: NSUTF8StringEncoding]];
+    uids = [contactsId objectEnumerator];
+    while ((uid = [uids nextObject]))
+      {
+        currentChild = [sourceFolder lookupName: uid
+                                      inContext: [self context]
+                                        acquire: NO];
+        if ([currentChild respondsToSelector: @selector (vCard)])
+          [content appendFormat: @"%@", [[currentChild ldifRecord] ldifRecordAsString]];
+        else if ([currentChild respondsToSelector: @selector (vList)])
+          [content appendFormat: @"%@", [[currentChild vList] ldifString]];
+        [content appendString: @"\n"];
+      }
+
+    response = [context response];
+    [response setHeader: @"application/directory; charset=utf-8"
+                forKey: @"content-type"];
+    filename = [NSString stringWithFormat: @"%@.ldif",
+                        [[sourceFolder displayName] asQPSubjectString: @"utf-8"]];
+    disposition = [NSString stringWithFormat: @"attachment; filename=\"%@\"", filename];
+    [response setHeader: disposition forKey: @"Content-Disposition"];
+    [response setContent: [content dataUsingEncoding: NSUTF8StringEncoding]];
+  }
 
   return response;
 }
@@ -463,4 +478,29 @@ static NSArray *photoTags = nil;
   return rc;
 }
 
+- (WOResponse *) mobileconfigAction
+{
+  SOGoContactGCSFolder *folder;
+  NSString *davURL, *plistContent, *disposition;
+  WOResponse *response;
+
+  folder = [self clientObject];
+  davURL = [folder davURLAsString];
+  plistContent = [SOGoMobileProvision plistForContactsWithContext: context andPath: davURL andName: [NSString stringWithFormat: @"%@ - %@", [folder owner], [folder realNameInContainer]]];
+ 
+  if (nil != plistContent) {
+    response = [self responseWithStatus: 200
+                            andString: plistContent];
+    [response setHeader: @"application/x-plist; charset=utf-8" 
+                forKey: @"content-type"];
+    disposition = [NSString stringWithString: @"attachment; filename=\"contacts.mobileconfig\""];
+    [response setHeader: disposition forKey: @"Content-Disposition"];
+  } else {
+    response = [self responseWithStatus: 500
+                            andString: @"Error while generating profile"];
+  }
+
+  return response;
+}
+
 @end /* UIxContactFolderActions */
