@@ -1,8 +1,6 @@
 /* UIxMailPartICalActions.h - this file is part of SOGo
  *
- * Copyright (C) 2007 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2007-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,13 +21,13 @@
 #ifndef UIXMAILPARTICALACTIONS_H
 #define UIXMAILPARTICALACTIONS_H
 
-#import <NGObjWeb/WODirectAction.h>
-
 @class iCalCalendar;
 @class SOGoMailBodyPart;
 @class WOResponse;
 
-@interface UIxMailPartICalActions : WODirectAction
+#import <UI/SOGoUI/SOGoDirectAction.h>
+
+@interface UIxMailPartICalActions : SOGoDirectAction
 
 - (WOResponse *) acceptAction;
 - (WOResponse *) declineAction;
