@@ -278,7 +278,7 @@ static NSArray *reminderValues = nil;
   userSource = [user authenticationSource];
   
   for(policy in [userSource userPasswordPolicy]) {
-    [translations setObject:[self labelForKey:[policy objectForKey:@"label"]] 
+    [translations setObject:[self commonLabelForKey:[policy objectForKey:@"label"]] 
                      forKey: [policy objectForKey:@"label"]];
   }
   translatedUserPolicy = [SOGoPasswordPolicy createPasswordPolicyLabels: [userSource userPasswordPolicy] 
@@ -1000,12 +1000,16 @@ static NSArray *reminderValues = nil;
 //
 - (NSArray *) daysBetweenResponsesList
 {
-  static NSArray *daysBetweenResponses = nil;
+  static NSMutableArray *daysBetweenResponses = nil;
 
   if (!daysBetweenResponses)
     {
-      daysBetweenResponses = [NSArray arrayWithObjects: @"1", @"2", @"3",
+      daysBetweenResponses = [NSMutableArray arrayWithObjects: @"1", @"2", @"3",
                                       @"5", @"7", @"14", @"21", @"30", nil];
+      if ([[user domainDefaults] vacationAllowZeroDays])
+        {
+          [daysBetweenResponses insertObject:@"0" atIndex:0];
+        }
       [daysBetweenResponses retain];
     }
 
