@@ -8,7 +8,8 @@
    * @constructor
    * @param {object} futureAccountData
    */
-    function Account(futureAccountData) {
+  function Account(futureAccountData) {
+    var _this = this;
     // Data is immediately available
     if (typeof futureAccountData.then !== 'function') {
       angular.extend(this, futureAccountData);
@@ -24,7 +25,12 @@
           identity.textSignature = _.map(element.contents(), 'textContent').join(' ').trim();
         }
       });
-      Account.$log.debug('Account: ' + JSON.stringify(futureAccountData, undefined, 2));
+      if (this.$mailboxes) {
+        // Create instances of Mailbox
+        Account.$Mailbox.$unwrapCollection(this, Account.$q.when({ mailboxes: this.$mailboxes })).then(function(collection) {
+          _this.$mailboxes = collection;
+        });
+      }
     }
     else {
       // The promise will be unwrapped first
@@ -339,7 +345,7 @@
    * @function $getMailboxByPath
    * @memberof Account.prototype
    * @desc Recursively find a mailbox using its path
-   * @returns a promise of the HTTP operation
+   * @returns the Mailbox instance or null if not found
    */
   Account.prototype.$getMailboxByPath = function(path) {
     var mailbox = null,
@@ -359,6 +365,9 @@
         };
     mailbox = _find(this.$mailboxes);
 
+    if (mailbox == null)
+      throw Error('No mailbox found matching path ' + path);
+
     return mailbox;
   };
 
@@ -551,8 +560,8 @@
    * @desc Return a sanitized object used to send to the server.
    * @return an object literal copy of the Account instance
    */
-  Account.prototype.$omit = function () {
-    var account = {}, identities = [], defaultIdentity = false;
+  Account.prototype.$omit = function (deep) {
+    var account = {}, identities = [], mailboxes = [], defaultIdentity = false;
 
     angular.forEach(this, function(value, key) {
       if (key != 'constructor' && key !='identities' && key[0] != '$') {
@@ -560,8 +569,15 @@
       }
     });
 
+    if (deep) {
+      _.forEach(this.$mailboxes, function(mailbox) {
+        mailboxes.push(mailbox.$omit(deep));
+      });
+      account.$mailboxes = mailboxes;
+    }
+
     _.forEach(this.identities, function (identity) {
-      if (!identity.isReadOnly)
+      if (!identity.isReadOnly || deep)
         identities.push(_.pick(identity, ['email', 'fullName', 'replyTo', 'signature', 'isDefault']));
       if (identity.isDefault)
         defaultIdentity = identity;
