@@ -31,11 +31,12 @@
    * @desc The factory we'll use to register with Angular
    * @returns the Mailbox constructor
    */
-  Mailbox.$factory = ['$q', '$timeout', '$log', 'sgSettings', 'Resource', 'Message', 'Acl', 'Preferences', 'sgMailbox_PRELOAD', 'sgMailbox_BATCH_DELETE_LIMIT', function($q, $timeout, $log, Settings, Resource, Message, Acl, Preferences, PRELOAD, BATCH_DELETE_LIMIT) {
+  Mailbox.$factory = ['$q', '$timeout', '$log', '$rootScope', 'sgSettings', 'Resource', 'Message', 'Acl', 'Preferences', 'sgMailbox_PRELOAD', 'sgMailbox_BATCH_DELETE_LIMIT', function ($q, $timeout, $log, $rootScope, Settings, Resource, Message, Acl, Preferences, PRELOAD, BATCH_DELETE_LIMIT) {
     angular.extend(Mailbox, {
       $q: $q,
       $timeout: $timeout,
       $log: $log,
+      $rootScope: $rootScope,
       $$resource: new Resource(Settings.activeUser('folderURL') + 'Mail', Settings.activeUser()),
       $Message: Message,
       $$Acl: Acl,
@@ -45,6 +46,7 @@
       $refreshTimeout: null,
       $virtualMode: false,
       $virtualPath: false,
+      $searchMode: false,
       PRELOAD: PRELOAD,
       BATCH_DELETE_LIMIT: BATCH_DELETE_LIMIT
     });
@@ -105,11 +107,12 @@
         // Local recursive function
         createMailboxes = function(level, mailbox) {
           mailbox.isSentFolder = mailbox.isSentFolder || mailbox.type == 'sent';
+          mailbox.isDraftsFolder = mailbox.isDraftsFolder || mailbox.type == 'draft';
           for (var i = 0; i < mailbox.children.length; i++) {
             mailbox.children[i].level = level;
             mailbox.children[i] = new Mailbox(account, mailbox.children[i]);
-            if (mailbox.isSentFolder)
-              mailbox.children[i].isSentFolder = true;
+            mailbox.children[i].isSentFolder = mailbox.isSentFolder;
+            mailbox.children[i].isDraftsFolder = mailbox.isDraftsFolder;
             createMailboxes(level+1, mailbox.children[i]);
           }
         };
@@ -168,6 +171,9 @@
       this.$visibleMessages = this.$messages;
       this.$selectedMessages = [];
     }
+    if (angular.isUndefined(this.$highlightWords)) {
+      this.$highlightWords = [];
+    }
     angular.extend(this, data);
     if (this.path) {
       this.id = this.$id();
@@ -203,6 +209,10 @@
         this.$displayName = l('JunkFolderName');
         this.$icon = 'thumb_down';
       }
+      else if (this.type == 'templates') {
+        this.$displayName = l('TemplatesFolderName');
+        this.$icon = 'mail_outline';
+      }
       else if (this.type == 'additional') {
         this.$icon = 'folder';
       }
@@ -237,6 +247,16 @@
       Mailbox.selectedFolder = this;
   };
 
+  /**
+   * @function setSearchMode
+   * @memberof Mailbox.prototype
+   * @desc Set search mode for controller
+   * @param {array} searchMode - a boolean
+   */
+  Mailbox.prototype.setSearchMode = function (searchMode) {
+    Mailbox.$searchMode = searchMode;
+  };
+
   /**
    * @function getLength
    * @memberof Mailbox.prototype
@@ -380,6 +400,28 @@
       // Sorting preferences are common to all mailboxes
       angular.extend(Mailbox.$query, sortingAttributes);
 
+    if (filters && filters.length > 0) {
+      // Remove highlight words
+      this.$highlightWords = [];
+      filters.forEach(filter => {
+        if ("subject_or_from" == filter.searchBy
+          || "subject_or_to" == filter.searchBy
+          || "contains" == filter.searchBy
+          || "body" == filter.searchBy
+          || "from" == filter.searchBy
+          || "to" == filter.searchBy
+          || "subject" == filter.searchBy) {
+          var words = filter.searchInput.split(" ");
+          words.forEach(word => {
+            var cleanedWord = word.trim().toLowerCase();
+            if (!this.$highlightWords.includes(cleanedWord)) {
+              this.$highlightWords.push(cleanedWord);
+            }
+          });
+        }
+      });
+    }
+
     angular.extend(options, { sortingAttributes: Mailbox.$query });
     if (angular.isDefined(filters)) {
       options.filters = _.reject(angular.copy(filters), function(filter) {
@@ -398,7 +440,9 @@
         }
       });
     }
-    else if (!sortingAttributes && this.$syncToken) {
+    else if (!sortingAttributes && !this.$flaggedOnly && !this.$unseenOnly && this.$syncToken) {
+      // Fetch changes only if sorting attributes haven't changed, and view is not limited to
+      // unseen messages or flagged messages.
       action = 'changes';
       options.syncToken = this.$syncToken;
     }
@@ -741,6 +785,23 @@
     });
   };
 
+  /**
+   * @function forwardMessages
+   * @memberof Mailbox.prototype
+   * @desc Attach multiple messages to a new draft
+   * @returns a promise of the HTTP operation with the draft coordinates
+   */
+  Mailbox.prototype.forwardMessages = function(messages) {
+    var _this = this,
+        uids = _.map(messages, 'uid');
+
+    return Mailbox.$$resource.post(this.id, 'forwardMessages', { uids: uids }).then(function(data) {
+      Mailbox.$log.debug('Forward selected messages: ' + JSON.stringify(data, undefined, 2));
+      var message = new Mailbox.$Message(data.accountId, _this.$account.$getMailboxByPath(data.mailboxPath), data);
+      return message;
+    });
+  };
+
   /**
    * @function saveSelectedMessages
    * @memberof Mailbox.prototype
@@ -845,9 +906,6 @@
           data = { uids: currentUids };
       if (options) angular.extend(data, options);
       return Mailbox.$$resource.post(_this.id, 'batchDelete', data).then(function(data) {
-        if (data.unseenCount) {
-          _this.unseenCount = data.unseenCount;
-        }
         if (end < uids.length) {
           _this.$_deleteMessages(currentUids);
           return _deleteMessages(end, Math.min(end + batchSize, uids.length));
@@ -856,6 +914,9 @@
           // Last API call; update inbox quota
           if (data.quotas)
             _this.$account.updateQuota(data.quotas);
+          if (angular.isDefined(data.unseenCount))
+            _this.unseenCount = data.unseenCount;
+
           return _this.$_deleteMessages(currentUids);
         }
       });
@@ -911,7 +972,7 @@
     uids = _.map(messages, 'uid');
     return Mailbox.$$resource.post(this.id, 'moveMessages', {uids: uids, folder: folder})
       .then(function(data) {
-        if (data.unseenCount) {
+        if (angular.isDefined(data.unseenCount)) {
           _this.unseenCount = data.unseenCount;
         }
         _this.$selectedMessages = []; // reset selection
@@ -973,11 +1034,18 @@
    */
   Mailbox.prototype.$reset = function(options) {
     var _this = this;
+    var account;
     angular.forEach(this.$shadowData, function(value, key) {
       delete _this[key];
     });
+    account = Object.assign({}, _this.$account)
     angular.extend(this, this.$shadowData);
     this.$shadowData = this.$omit();
+    this.account = account;
+    if (options && options.unseenCount) {
+      this.unseenCount = options.unseenCount;
+      delete options["unseenCount"];
+    }
     if (options && options.filter) {
       this.$messages = [];
       this.$visibleMessages = [];
@@ -991,8 +1059,16 @@
    * @desc Return a sanitized object used to send to the server.
    * @return an object literal copy of the Mailbox instance
    */
-  Mailbox.prototype.$omit = function() {
-    var mailbox = {};
+  Mailbox.prototype.$omit = function(deep) {
+    var mailbox = {},
+        _visit = function(children) {
+          var childrenArray = [];
+          _.forEach(children, function(o) {
+            childrenArray.push(o.$omit(deep));
+          });
+          return childrenArray;
+        };
+
     angular.forEach(this, function(value, key) {
       if (key != 'constructor' &&
           key != 'children' &&
@@ -1003,6 +1079,9 @@
         mailbox[key] = value;
       }
     });
+    if (deep && this.children) {
+      mailbox.children = _visit(this.children);
+    }
     return mailbox;
   };
 
@@ -1034,6 +1113,7 @@
    * @returns a promise of the HTTP operation
    */
   Mailbox.prototype.$unwrap = function(futureMailboxData) {
+    Mailbox.$rootScope.$broadcast('beforeListRefresh');
     var _this = this,
         deferred = Mailbox.$q.defer();
 
@@ -1078,7 +1158,7 @@
             }
           }
         }
-        if (data.unseenCount) {
+        if (angular.isDefined(data.unseenCount)) {
           _this.unseenCount = data.unseenCount;
         }
 
@@ -1086,6 +1166,7 @@
           // Initialization phase, we received complete list of UIDs
           Mailbox.$log.debug('unwrapping ' + data.uids.length + ' messages');
 
+          hasNewMessages = true;
           _this.init(data);
 
           // First entry of 'uids' are keys when threaded view is enabled
@@ -1155,6 +1236,7 @@
 
         Mailbox.$log.debug('mailbox ' + _this.id + ' ready');
         _this.$isLoading = false;
+        Mailbox.$rootScope.$broadcast('listRefreshed');
         deferred.resolve(_this.$messages);
       });
     }, function(data) {
@@ -1213,4 +1295,40 @@
     Mailbox.$$resource.post(this.id, action);
   };
 
+  /**
+   * @function setHighlightWords
+   * @memberof Mailbox.prototype
+   * @desc Set highlight words when searching
+   * @param {array} highlightWords - a list of words
+   */
+  Mailbox.prototype.setHighlightWords = function (highlightWords) {
+    this.$highlightWords = highlightWords;
+  };
+
+  /**
+   * @function getHighlightWords
+   * @memberof Mailbox.prototype
+   * @desc Get highlight words when searching
+   * @returns a list of words
+   */
+  Mailbox.prototype.getHighlightWords = function () {
+    return this.$highlightWords;
+  };
+
+  /**
+   * @function cleanMailbox
+   * @memberof Mailbox.prototype
+   * @desc Cleans up the mailbox by applying the specified parameters. 
+   *       This can include operations such as moving emails to trash, 
+   *       filtering emails based on a duration, and applying actions to subfolders.
+   * @param {Object} parameters - An object containing the parameters for cleaning the mailbox.
+   * @param {boolean} [parameters.applyToSubfolders=false] - Whether to apply the cleaning operation to subfolders.
+   * @param {boolean} [parameters.moveToTrash=false] - Whether to move the emails to the trash folder.
+   * @param {string|null} [parameters.filterDuration=null] - A duration filter (e.g., "3m", "6m") to select emails older than the specified duration.
+   * @returns {Promise} A promise that resolves when the cleaning operation is completed, or rejects with an error if the operation fails.
+   */
+  Mailbox.prototype.cleanMailbox = function (parameters) {
+    return parameters.folders.length > 0 ? Mailbox.$$resource.post(this.id.split("/")[0], 'cleanMailbox', parameters) : Mailbox.$$resource.post(this.id, 'cleanMailbox', parameters);
+  };
+  
 })();
