@@ -33,6 +33,9 @@
       this.selectedFolder = stateMailbox;
       this.messageDialog = null; // also access from Message controller
       this.mode = { search: false, multiple: 0 };
+      this.allSelected = false;
+      this.isLoadingMessage = false;
+      this.nextAction = null;
 
       if (!Mailbox.$virtualMode)
         this.selectedFolder.getLabels(); // fetch labels from server
@@ -47,10 +50,10 @@
         _.forEach(hotkeys, function(key) {
           sgHotkeys.deregisterHotkey(key);
         });
-        if (vm.mode.search) {
-          vm.mode.search = false;
-          vm.selectedFolder.$reset({ filter: true });
-        }
+        // if (vm.mode.search) {
+        //   vm.mode.search = false;
+        //   vm.selectedFolder.$reset({ filter: true });
+        // }
       });
 
       // Update window's title with unseen messages count of selected mailbox
@@ -79,7 +82,7 @@
         }
       }));
       keys.push(sgHotkeys.createHotkey({
-        key: l('hotkey_junk'),
+        key: l('shift+j'),
         description: l('Mark the selected messages as junk'),
         callback: vm.markOrUnMarkMessagesAsJunk
       }));
@@ -172,12 +175,16 @@
     };
 
     this.cancelSearch = function() {
+      // Clean highlights
+      if (vm.account) {
+        vm.account.$getMailboxes().$$state.value.forEach((mailbox) => {
+          mailbox.setHighlightWords([]);
+        });
+      }
       vm.mode.search = false;
       vm.selectedFolder.$filter(vm.service.$query).then(function() {
         if (vm.selectedFolder.$selectedMessage) {
-          $timeout(function() {
-            vm.selectedFolder.$topIndex = vm.selectedFolder.uidsMap[vm.selectedFolder.$selectedMessage];
-          });
+          vm.selectedFolder.$topIndex = vm.selectedFolder.uidsMap[vm.selectedFolder.$selectedMessage];
         }
       });
     };
@@ -203,9 +210,7 @@
       }
       url = url.join('/');
       popupWindow = $window.open(url, wId,
-                                 ["width=680",
-                                  "height=520",
-                                  "resizable=1",
+                                 ["resizable=1",
                                   "scrollbars=1",
                                   "toolbar=0",
                                   "location=0",
@@ -288,6 +293,10 @@
      * User has pressed up arrow key
      */
     function _nextMessage($event) {
+      if (vm.isLoadingMessage) {
+        vm.nextAction = { m: _nextMessage, p: $event };
+      }
+
       var index = vm.selectedFolder.$selectedMessageIndex();
 
       if (angular.isDefined(index)) {
@@ -301,7 +310,7 @@
         vm.selectedFolder.$topIndex = vm.selectedFolder.getLength();
       }
 
-      if (index > -1)
+      if (index > -1 && !vm.isLoadingMessage)
         vm.selectMessage(vm.selectedFolder.getItemAtIndex(index));
 
       $event.preventDefault();
@@ -313,6 +322,10 @@
      * User has pressed the down arrow key
      */
     function _previousMessage($event) {
+      if (vm.isLoadingMessage) {
+        vm.nextAction = { m: _previousMessage, p: $event };
+      }
+
       var index = vm.selectedFolder.$selectedMessageIndex();
 
       if (angular.isDefined(index)) {
@@ -324,7 +337,7 @@
         // No message is selected, show newest
         index = 0;
 
-      if (index < vm.selectedFolder.getLength())
+      if (index < vm.selectedFolder.getLength() && !vm.isLoadingMessage)
         vm.selectMessage(vm.selectedFolder.getItemAtIndex(index));
       else
         index = -1;
@@ -369,10 +382,35 @@
     }
 
     this.selectMessage = function(message) {
-      if (Mailbox.$virtualMode)
-        $state.go('mail.account.virtualMailbox.message', {mailboxId: encodeUriFilter(encodeUriFilter(message.$mailbox.path)), messageId: message.uid});
-      else
-        $state.go('mail.account.mailbox.message', {mailboxId: encodeUriFilter(encodeUriFilter(message.$mailbox.path)), messageId: message.uid});
+      if (Mailbox.$virtualMode) {
+        vm.isLoadingMessage = true;
+        $state.go('mail.account.virtualMailbox.message', { mailboxId: encodeUriFilter(encodeUriFilter(message.$mailbox.path)), messageId: message.uid }).then(function () {
+
+        }).catch((err) => {
+          console.error(err);
+        })
+          .finally(() => {
+            vm.isLoadingMessage = false;
+            if (vm.nextAction) {
+              vm.nextAction.m(vm.nextAction.p);
+              vm.nextAction = null;
+            }
+          });
+      } else {
+        vm.isLoadingMessage = true;
+        $state.go('mail.account.mailbox.message', { mailboxId: encodeUriFilter(encodeUriFilter(message.$mailbox.path)), messageId: message.uid }).then(function () {
+
+        }).catch((err) => {
+          console.error(err);
+        })
+          .finally(() => {
+            vm.isLoadingMessage = false;
+            if (vm.nextAction) {
+              vm.nextAction.m(vm.nextAction.p);
+              vm.nextAction = null;
+            }
+          });
+      }
     };
 
     this.toggleMessageSelection = function($event, message) {
@@ -549,9 +587,12 @@
         });
     };
 
-    this.moveSelectedMessages = function(dstFolder) {
+    this.moveSelectedMessages = function(dstFolder, message) {
       var moveSelectedMessage = vm.selectedFolder.hasSelectedMessage();
       var selectedMessages = vm.selectedFolder.selectedMessages();
+      if (message) {
+        selectedMessages.push(message);
+      }
       var count = vm.selectedFolder.selectedCount();
       if (_.size(selectedMessages) > 0)
         vm.selectedFolder.$moveMessages(selectedMessages, '/' + dstFolder).then(function(index) {
@@ -579,11 +620,13 @@
         var i = 0, length = folder.$messages.length;
         folder.$selectedMessages = [];
         for (; i < length; i++) {
-          folder.$messages[i].selected = true;
-          folder.$selectedMessages.push(folder.$messages[i]);
+          folder.$messages[i].selected = !vm.allSelected;
+          if(folder.$messages[i].selected)
+            folder.$selectedMessages.push(folder.$messages[i]);
+            count++;
         }
-        count += length;
       });
+      vm.allSelected = !vm.allSelected;
       vm.mode.multiple = count;
     };
 
