@@ -44,14 +44,14 @@
         //   Categories color stripes
         '    <div class="sg-category" ng-repeat="category in '+p+'block.component.categories"',
         '         ng-class="'+p+'(\'bg-category\' + category)"',
-        '         ng-style="'+p+'{ right: ($index * 3) + \'px\' }"></div>',
+        '         ng-style="'+p+'{ right: ($index * 10) + \'%\' }"></div>',
         '    <div class="text">',
         //     Priority
         '      <span ng-show="'+p+'block.component.c_priority" class="sg-priority">{{'+p+'block.component.c_priority}}</span>',
         //     Summary
         '      {{ '+p+'block.component.summary }}',
         //     Icons
-        '      <span class="icons">',
+        '      <span class="sg-icons">',
         //       Component is reccurent
         '        <md-icon ng-if="'+p+'block.component.occurrenceId">repeat</md-icon>',
         //       Component has an alarm
